summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/khighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/khighscore.h')
-rw-r--r--libkdegames/highscore/khighscore.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/libkdegames/highscore/khighscore.h b/libkdegames/highscore/khighscore.h
index 42c9fcda..ba7a4bd0 100644
--- a/libkdegames/highscore/khighscore.h
+++ b/libkdegames/highscore/khighscore.h
@@ -67,7 +67,7 @@ class KHighscorePrivate;
* single player, so the "best times" of a player. To write highscores for a
* specific player in a specific level you will have to use a more complex way:
* \code
- * TQString group = TQString("%1_%2").arg(player).arg(level);
+ * TQString group = TQString("%1_%2").tqarg(player).tqarg(level);
* table->setGroup(group);
* writeHighscore(table, player, level);
* \endcode
@@ -81,15 +81,16 @@ class KHighscorePrivate;
* Easy, what?
* @author Andreas Beckermann <b_mann@gmx.de>
**/
-class KDE_EXPORT KHighscore : public QObject
+class KDE_EXPORT KHighscore : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/** @obsolete
* Constructor. The highscore file is forced to be local to support
* games using the old behaviour.
*/
- KHighscore(TQObject* parent = 0);
+ KHighscore(TQObject* tqparent = 0);
/**
* Constructor.
@@ -97,10 +98,10 @@ public:
* @param forceLocal if true, the local highscore file is used even
* when the configuration has been set to use a system-wide file. This
* is convenient for converting highscores from legacy applications.
* @param parent parent widget for this widget
* @since 3.2
*/
- KHighscore(bool forceLocal, TQObject *parent);
+ KHighscore(bool forceLocal, TQObject *tqparent);
/**
* Read the current state of the highscore file. Remember that when
@@ -132,7 +133,7 @@ public:
* If the config file cannot be locked,
* the method waits for 1 second and, if it failed again, displays
* a message box asking for retry or cancel.
* @param widget used as the parent of the message box.
*
* @return false on error or if the config file is locked by another
* process. In such case, the config stays read-only.
@@ -193,7 +194,7 @@ public:
* @return The value of this entry+key pair or pDefault if the entry+key
* pair doesn't exist
**/
- TQString readEntry(int entry, const TQString& key, const TQString& pDefault = TQString::null) const;
+ TQString readEntry(int entry, const TQString& key, const TQString& pDefault = TQString()) const;
/**
* Read a numeric value.
@@ -273,15 +274,15 @@ public:
* Set the new highscore group. The group is being prefixed with
* "KHighscore_" in the table.
* @param groupname The new groupname. E.g. use "easy" for the easy
- * level of your game. If you use TQString::null (the default) the
+ * level of your game. If you use TQString() (the default) the
* default group is used.
**/
- void setHighscoreGroup(const TQString& groupname = TQString::null);
+ void setHighscoreGroup(const TQString& groupname = TQString());
/**
* @return The currently used group. This doesn't contain the prefix
* ("KHighscore_") but the same as setHighscoreGroup uses. The
- * default is TQString::null
+ * default is TQString()
**/
const TQString& highscoreGroup() const;
@@ -97,10 +98,10 @@ public:
* when the configuration has been set to use a system-wide file. This
* is convenient for converting highscores from legacy applications.
- * @param parent parent widget for this widget
+ * @param tqparent tqparent widget for this widget
* @since 3.2
*/
@@ -132,7 +133,7 @@ public:
* the method waits for 1 second and, if it failed again, displays
* a message box asking for retry or cancel.
- * @param widget used as the parent of the message box.
+ * @param widget used as the tqparent of the message box.
*
* @return false on error or if the config file is locked by another